@@ -14,14 +14,19 @@ class InvalidUsage(Exception):
 
     status_code = 400
     error = "Unknown error"
+    log_txt = "Unknown error"
 
-    def __init__(self, error=None, status_code=None, payload=None):
-        Exception.__init__(self)
+    def __init__(self, error=None, status_code=None, payload=None, log_txt=None):
+        Exception.__init__(self, error)
         if error is not None:
             self.error = error
         if status_code is not None:
             self.status_code = status_code
         self.payload = payload
+        if log_txt is not None:
+            self.log_txt = log_txt
+        else:
+            self.log_txt = self.error
 
     def to_dict(self):
         """
@@ -125,6 +130,7 @@ def initialize_errorhandlers(app):
 
     @app.errorhandler(InvalidUsage)
     @app.errorhandler(ObjectDoesNotExist)
+    @app.errorhandler(ObjectAlreadyExists)
     @app.errorhandler(NoPermission)
     @app.errorhandler(InvalidCredentials)
     @app.errorhandler(EndpointNotImplemented)
@@ -141,6 +147,7 @@ def initialize_errorhandlers(app):
         :return: an HTTP response
         :rtype: `Response`
         """
+        app.logger.error(error.log_txt)
         response = jsonify(error.to_dict())
         response.status_code = error.status_code
         return response
